==> dojo-1.10.6.tgz: package/cldr/nls/hr/japanese.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "M. y. GGGGG",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-dayperiod": "Prijepodne/popodne",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-minute": "Minuta",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-day-relative+-1": "jučer",
	"field-weekday": "Dan u tjednu",
	"dateFormatItem-yQQQ": "QQQ y. GGGGG",
	"field-day-relative+-2": "prekjučer",
	"field-era": "Era",
	"dateFormatItem-Gy": "y. GGG",
	"field-hour": "Sat",
	"dateFormatItem-y": "y. GGG",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-Ed": "E, d.",
	"dateFormatItem-yMMM": "LLL y. GGGGG",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"field-tue-relative+0": "ovaj utorak",
	"field-zone": "Vremenska zona",
	"field-tue-relative+1": "sljedeći utorak",
	"field-week-relative+-1": "prošli tjedan",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-sat-relative+-1": "prošla subota",
	"dateFormatItem-yMd": "d. M. y. GGGGG",
	"field-year-relative+-1": "prošle godine",
	"field-year": "Godina",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-week": "Tjedan",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-month": "Mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"field-fri-relative+-1": "prošli petak",
	"dateFormatItem-MMMMd": "d. MMMM",
	"dateFormatItem-yMMMd": "d. MMM y. GGGGG",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "prošli utorak",
	"field-day": "Dan",
	"dateFormatItem-MEd": "E, d. M.",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-second-relative+0": "sada",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-yMMMEd": "E, d. MMM y. GGGGG",
	"dateFormatItem-Md": "d. M.",
	"dateFormatItem-yMEd": "E, d. M. y. GGGGG",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-relative+-1": "prošli četvrtak"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/hr/japanese.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "M. y. GGGGG",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-dayperiod": "AM/PM",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-minute": "Minuta",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-day-relative+-1": "jučer",
	"field-weekday": "Dan u tjednu",
	"dateFormatItem-yQQQ": "QQQ y. GGGGG",
	"field-day-relative+-2": "prekjučer",
	"field-era": "Era",
	"dateFormatItem-Gy": "y. GGG",
	"field-hour": "Sat",
	"dateFormatItem-y": "y. GGG",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-Ed": "E, d.",
	"dateFormatItem-yMMM": "LLL y. GGGGG",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"field-tue-relative+0": "ovaj utorak",
	"field-zone": "Vremenska zona",
	"field-tue-relative+1": "sljedeći utorak",
	"field-week-relative+-1": "prošli tjedan",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-sat-relative+-1": "prošla subota",
	"dateFormatItem-yMd": "d. M. y. GGGGG",
	"field-year-relative+-1": "prošle godine",
	"field-year": "Godina",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-week": "Tjedan",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-month": "Mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"field-fri-relative+-1": "prošli petak",
	"dateFormatItem-MMMMd": "d. MMMM",
	"dateFormatItem-yMMMd": "d. MMM y. GGGGG",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "prošli utorak",
	"field-day": "Dan",
	"dateFormatItem-MEd": "E, d. M.",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-second-relative+0": "sada",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-yMMMEd": "E, d. MMM y. GGGGG",
	"dateFormatItem-Md": "d. M.",
	"dateFormatItem-yMEd": "E, d. M. y. GGGGG",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-relative+-1": "prošli četvrtak"
}
//end v1.x content
);
